import React from 'react';
import { storiesOf, action, linkTo } from '@kadira/storybook'
import {
  App,
  Pane,
  Text,
  Content,
  NavigationBar,
  Avatar,
  Box,
  Triangle,
  Code,
  Button
} from '../components'

const AvatarWithTriangle = () => <Box display='inline-flex' alignItems='center'>
  <Avatar marginLeft={2} marginRight={2} src='' imageSize='small'>Segment Sloth</Avatar>
  <Triangle aim='down'  display='inline-flex' fill='white' />
</Box>

export default function navigationBarStory (module) {
  storiesOf('Navigation Bar', module)
    .add('usage', () => (
      <App>
        <Pane white padding={10}>
          <Content markdown>
{`
# Navigation Bar

The NavigationBar component. Composes \`<Pane />\`.

\`\`\`
const AvatarWithTriangle = () => <Box  display='inline-flex' alignItems='center'>
  <Avatar marginLeft={2} marginRight={2} src='' imageSize='small'>Segment Sloth</Avatar>
  <Triangle aim='down'  display='inline-flex' fill='white' />
</Box>

<NavigationBar left={'Sloth Corp Media'} right={<AvatarWithTriangle />}>Workspaces</NavigationBar>
\`\`\`

`}
          </Content>
          <NavigationBar left={'Sloth Corp Media'} right={<AvatarWithTriangle />}>Workspaces</NavigationBar>
          <Content markdown>
{`
prop | type | default | description
-----|------| --------|-------------
\`children\` | node/string | undefined | if string wrapped in \`<NavigationBarTitle />\`
\`left\` | node | undefined | optional component next to logo
\`right\` | node | undefined | optional component in right corner
\`logo\`| node | \`<NavigationBarLogo />\` | formatted Segment logo
\`height\`| string | 58px | formatted Segment logo
`}
          </Content>
        </Pane>
      </App>
    ))
    .add('with title only', () => (
      <NavigationBar>Workspaces</NavigationBar>
    ))
    .add('with title and left component', () => (
      <NavigationBar left={'Sloth Corp Media'}>Workspaces</NavigationBar>
    ))
    .add('with title and right component', () => (
      <NavigationBar right={<AvatarWithTriangle />}>Workspaces</NavigationBar>
    ))
    .add('with title and left + right component', () => (
      <NavigationBar left={'Sloth Corp Media'} right={<AvatarWithTriangle />}>Workspaces</NavigationBar>
    ))
}
