import React from 'react';
import { storiesOf, action, linkTo } from '@kadira/storybook'
import {
  App,
  Sheet,
  Pane,
  Button,
  Content
} from '../components'

class SheetTrigger extends React.Component {
  constructor() {
    super()
    this.toggle = this.toggle.bind(this)
    this.state = {
      isOpen: false
    }
  }

  toggle() {
    this.setState({ isOpen: !this.state.isOpen })
  }

  render() {
    return (
      <Pane>
        <Button primary onClick={this.toggle}>Open Sheet</Button>
        <Sheet isOpen={this.state.isOpen} onClose={this.toggle}>
          <Pane padding>Hello World</Pane>
        </Sheet>
      </Pane>
    )
  }
}

export default function sheetStory (module) {
  storiesOf('Sheet', module)
    .add('usage', () => (
      <App white>
        <Pane padding={10}>
          <Content markdown>
{`
# Sheet

The Sheet component. Implement the \`<Pane />\` component.\

* Don't put spacing on the Sheet itself, the close button will me misaligned

\`\`\`
class SheetTrigger extends React.Component {
  constructor() {
    super()
    this.toggle = this.toggle.bind(this)
    this.state = {
      isOpen: false
    }
  }

  toggle() {
    this.setState({ isOpen: !this.state.isOpen })
  }

  render() {
    return (
      <Pane>
        <Button primary onClick={this.toggle}>Open Sheet</Button>
        <Sheet isOpen={this.state.isOpen} onClose={this.toggle}>
          <Pane padding>Hello World</Pane>
        </Sheet>
      </Pane>
    )
  }
}

<SheetTrigger />
\`\`\`

`}
          </Content>
          <SheetTrigger />
          <Content markdown>
{`
prop | type | default | description
-----|------| --------|-------------
\`isOpen\` | boolean | undefined | is the sheet open
\`onClose\` | function | undefined | onClose handler to manage state
\`width\`| string | \`680px\` | width of the Sheet
`}
          </Content>
        </Pane>
      </App>
    )).add('standalone', () => (
      <SheetTrigger />
    ))
}
